﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web.UI.WebControls;
using AdvancedBudget.CW.Graphs;
using AdvancedBudget.Common.Descriptor;
using AdvancedBudget.Common.Extensions;
using PX.Web.UI;

public partial class Page_CWAB4010 : PX.Web.UI.PXPage
{
    protected void Page_Init(object sender, EventArgs e)
    {
        var graph = ds.DataGraph as CWABEventMaint;
        if (graph != null)
        {
            var accountCodes = graph.GetAccountCodes(graph.Filter.Current.ViewId);
            GenerateAccountColumns(accountCodes);
        }
    }

    protected void edViewId_OnValueChanged(object sender, EventArgs eventArgs)
    {
        var value = sender.GetPropertyValue<string>("Value");
        var graph = ds.DataGraph as CWABEventMaint;
        if (!string.IsNullOrEmpty(value) && graph != null)
        {
            var existingColumns = gridEvents.Columns.Items
                .Where(x => !x.Label.Contains(Constants.RatePostfix)
                            && !x.Label.Contains(Constants.QtyPostfix)
                            && !x.Label.Contains(Constants.ExtPostfix)
                            && !x.Label.Contains(Constants.EventTotal))
                .ToList();
            ResetAssumptionColumns(existingColumns);
            var accountCodes = graph.GetAccountCodes(value);
            GenerateAccountColumns(accountCodes);
        }
    }

    private void ResetAssumptionColumns(IEnumerable<PXGridColumn> existingColumns)
    {
        gridEvents.Columns.Clear();
        foreach (var column in existingColumns)
        {
            gridEvents.Columns.Add(column);
        }
    }

    private void GenerateAccountColumns(IEnumerable<KeyValuePair<string, string>> accountCodes)
    {
        foreach (var accountCode in accountCodes)
        {
            CreateColumn(accountCode, Constants.QtyPostfix);
            CreateColumn(accountCode, Constants.RatePostfix);
            CreateColumn(accountCode, Constants.ExtPostfix);
        }
        CreateColumn(null, Constants.EventTotal);
    }

    private void CreateColumn(KeyValuePair<string, string>? account, string postfix)
    {
        var fieldName = string.Format(Constants.ColumnDataField, postfix,
            account.HasValue
                ? account.Value.Key
                : string.Empty);
        var column = CreateGridColumn(fieldName);
        column.Header.Text = string.Format(Constants.ColumnDisplayName, postfix,
            account.HasValue
                ? account.Value.Value
                : string.Empty);
        gridEvents.Columns.Add(column);
    }

    private static PXGridColumn CreateGridColumn(string fieldName)
    {
        return new PXGridColumn
        {
            DataField = fieldName,
            DataType = TypeCode.Decimal,
            Decimals = 2,
            TextAlign = HorizontalAlign.Right,
            AllowNull = false,
            RenderEditorText = true,
            AutoCallBack = true,
            CommitChanges = true,
            Width = Unit.Pixel(150)
        };
    }
}