﻿using System;
using System.Web.UI.WebControls;
using System.Collections.Generic;
using System.Linq;
using AdvancedBudget.CW.Graphs;
using AdvancedBudget.Common.Descriptor;
using AdvancedBudget.Common.Extensions;
using PX.Web.UI;

public partial class Page_CWAB5010 : PXPage
{
    protected void Page_Init(object sender, EventArgs e)
    {
        var graph = ds.DataGraph as CWABEmployeeBudgetMaint;
        if (graph != null)
        {
            var maxFinYear = graph.GetMasterFinYear().Year;
            var maxPeriods = graph.GetNumberOfPeriods(maxFinYear);
            GenerateAssumptionColumns(maxPeriods, null, "grdEmployeeBudgetDistribution",
                Constants.PeriodPrefix);
            GenerateAssumptionColumns(maxPeriods, "formSalarySplit", "gridSalarySplit",
                Constants.SalarySplitPeriodPrefix);
            GenerateAssumptionColumns(maxPeriods, "formOvertimeSplit", "gridOvertimeSplit",
                Constants.OvertimeSplitPeriodPrefix);
        }
    }

    protected void edFiscalYear_OnValueChanged(object sender, EventArgs eventArgs)
    {
        var value = sender.GetPropertyValue<string>("Value");
        var distributionsGrid = (PXGrid)tab.FindControl("grdEmployeeBudgetDistribution");
        var salarySplitGrid = (PXGrid)tab.FindControl("formSalarySplit").FindControl("gridSalarySplit");
        var overtimeSplitGrid = (PXGrid)tab.FindControl("formOvertimeSplit").FindControl("gridOvertimeSplit");
        var graph = ds.DataGraph as CWABDistributionAssumptionsMaint;
        if (!string.IsNullOrEmpty(value) && graph != null)
        {
            var existingDistributionColumns = distributionsGrid.Columns.Items
                .Where(x => !x.Label.Contains(Constants.PeriodPrefix)).ToList();
            var existingSalaryColumns = salarySplitGrid.Columns.Items
                .Where(x => !x.Label.Contains(Constants.SalarySplitPeriodPrefix)).ToList();
            var existingOvertimeColumns = overtimeSplitGrid.Columns.Items
                .Where(x => !x.Label.Contains(Constants.OvertimeSplitPeriodPrefix)).ToList();
            ResetAssumptionColumns(existingDistributionColumns, null, "grdEmployeeBudgetDistribution");
            ResetAssumptionColumns(existingSalaryColumns, "formSalarySplit", "gridSalarySplit");
            ResetAssumptionColumns(existingSalaryColumns, "formOvertimeSplit", "gridOvertimeSplit");
            GenerateAssumptionColumns(graph.GetNumberOfPeriods(value), null, "grdEmployeeBudgetDistribution",
                Constants.PeriodPrefix);
            GenerateAssumptionColumns(graph.GetNumberOfPeriods(value), "formSalarySplit", "gridSalarySplit",
                Constants.SalarySplitPeriodPrefix);
            GenerateAssumptionColumns(graph.GetNumberOfPeriods(value), "formOvertimeSplit", "gridOvertimeSplit",
                Constants.OvertimeSplitPeriodPrefix);
        }
    }

    private void ResetAssumptionColumns(IEnumerable<PXGridColumn> existingColumns, string formId, string gridId)
    {
        PXGrid grid = null;
        if (formId != null)
        {
            grid = (PXGrid)tab.FindControl(formId).FindControl(gridId);
        }
        else
        {
            grid = (PXGrid)tab.FindControl(gridId);
        }
        grid.Columns.Clear();
        foreach (var column in existingColumns)
        {
            grid.Columns.Add(column);
        }
    }

    private void GenerateAssumptionColumns(int periods, string formId, string gridId, string prefix)
    {
        for (var i = 1; i <= periods; i++)
        {
            var fieldName = prefix + i;
            var column = CreateGridColumn(fieldName);
            column.Header.Text = fieldName;
            PXGrid grid = null;
            if (formId != null)
            {
                grid = (PXGrid)tab.FindControl(formId).FindControl(gridId);
            }
            else
            {
                grid = (PXGrid)tab.FindControl(gridId);
            }
            grid.Columns.Add(column);
        }
    }

    private static PXGridColumn CreateGridColumn(string fieldName)
    {
        return new PXGridColumn
        {
            DataField = fieldName,
            DataType = TypeCode.Decimal,
            Decimals = 2,
            TextAlign = HorizontalAlign.Right,
            AllowNull = true,
            RenderEditorText = true,
            AutoCallBack = true,
            Width = Unit.Pixel(70)
        };
    }
}