﻿using System;
using System.Web.UI.WebControls;
using System.Collections.Generic;
using System.Linq;
using AdvancedBudget.CW.Graphs;
using AdvancedBudget.Common.Descriptor;
using AdvancedBudget.Common.Extensions;
using PX.Web.UI;

public partial class Page_CWAB8020 : PX.Web.UI.PXPage
{
    protected void Page_Init(object sender, EventArgs e)
    {
        var graph = ds.DataGraph as CWABBusinessAccountSubledgerBudgetMaint;
        if (graph != null)
        {
            var maxPeriods = graph.GetNumberOfPeriods();
            GenerateAssumptionColumns(maxPeriods);
        }
    }

    protected void edFiscalYear_OnValueChanged(object sender, EventArgs eventArgs)
    {
        var value = sender.GetPropertyValue<string>("Value");
        var graph = ds.DataGraph as CWABBusinessAccountSubledgerBudgetMaint;
        if (!string.IsNullOrEmpty(value) && graph != null)
        {
            var existingColumns = grdBusinessAccountViewDetails.Columns.Items
                .Where(x => !x.Label.Contains(Constants.PeriodPrefix)).ToList();
            ResetAssumptionColumns(existingColumns);
            GenerateAssumptionColumns(graph.GetNumberOfPeriods(value));
        }
    }

    private void ResetAssumptionColumns(IEnumerable<PXGridColumn> existingColumns)
    {
        grdBusinessAccountViewDetails.Columns.Clear();
        foreach (var column in existingColumns)
        {
            grdBusinessAccountViewDetails.Columns.Add(column);
        }
    }

    private void GenerateAssumptionColumns(int periods)
    {
        for (var i = 1; i <= periods; i++)
        {
            var fieldName = Constants.PeriodPrefix + i;
            var column = CreateGridColumn(fieldName);
            column.Header.Text = fieldName;
            grdBusinessAccountViewDetails.Columns.Add(column);
        }
    }

    private static PXGridColumn CreateGridColumn(string fieldName)
    {
        return new PXGridColumn
        {
            DataField = fieldName,
            DataType = TypeCode.Decimal,
            Decimals = 2,
            TextAlign = HorizontalAlign.Right,
            AllowNull = false,
            RenderEditorText = true,
            AutoCallBack = true,
            Width = Unit.Pixel(70)
        };
    }
}